==> haskell-xss-sanitize-0.3.7-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xss-sanitize
version:              0.3.7
visibility:           public
id:                   xss-sanitize-0.3.7-3CIPBjKJZj9438wlYhD1D2
key:                  xss-sanitize-0.3.7-3CIPBjKJZj9438wlYhD1D2
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  6f144a59f99d795409d59d1884f8ac68
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xss-sanitize-0.3.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xss-sanitize-0.3.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7-3CIPBjKJZj9438wlYhD1D2
depends:
    attoparsec-0.14.4-3hmNOn9KsQkLastvrl1LA3 base-4.15.1.0
    containers-0.6.4.1 css-text-0.1.3.0-7i5R7HQLXcIAfXjtvT74EE
    network-uri-2.6.4.1-IAkqAvJDjrn36sgBWLtC3A
    tagsoup-0.14.8-18MgQP8GH4PFp01uUBh7dv text-1.2.5.0
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.7-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xss-sanitize
version:              0.3.7
visibility:           public
id:                   xss-sanitize-0.3.7-IuazsvvVTBy9ynCC8CgzRI
key:                  xss-sanitize-0.3.7-IuazsvvVTBy9ynCC8CgzRI
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  7b9853cf6b2a6274c02b1a9e65ea20a1
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xss-sanitize-0.3.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xss-sanitize-0.3.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7-IuazsvvVTBy9ynCC8CgzRI
depends:
    attoparsec-0.14.4-3b5hJmAVxMZ2YoY0FeNqg3 base-4.15.1.0
    containers-0.6.4.1 css-text-0.1.3.0-HtpdOG1sqlI4b3lcwvnFKy
    network-uri-2.6.4.1-4xrPI2Tj8np6ivptg0MZK4
    tagsoup-0.14.8-6kBPNJ4xXCrFwbuXCemn5h text-1.2.5.0
    utf8-string-1.0.2-FOQgGpXm4p2BxMMm2pyYrn

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
